pub fn variogram_ma_structured(
f: ArrayView2<'_, f64>,
mask: ArrayView2<'_, bool>,
estimator_type: char,
num_threads: Option<usize>,
) -> Array1<f64>Expand description
Variogram estimation of a masked field on a structured grid.
Calculates the empirical variogram according to the equations shown in the module documentation.
Arguments
f- the spatially distributed datamask- the mask for the datafestimator_type- the estimator function, can be- ‘m’ - Matheron, the standard method of moments by Matheron
- ‘c’ - Cressie, an estimator more robust to outliers
num_threads- the number of parallel threads used, if None, use rayon’s default